@@ -39,4 +39,30 @@ typedef int ssize_t;
 # define S_ISBLK(m) (((m) & S_IFMT) == S_IFBLK)
 #endif
 
+/* access() mode flags */
+#ifndef R_OK
+#define R_OK    4
 #endif
+#ifndef W_OK
+#define W_OK    2
+#endif
+#ifndef F_OK
+#define F_OK    0
+#endif
+#endif
+
+/* Standard file descriptors.  */
+#ifndef STDIN_FILENO
+#define STDIN_FILENO    0
+#endif
+#ifndef STDOUT_FILENO
+#define STDOUT_FILENO   1
+#endif
+#ifndef STDERR_FILENO
+#define STDERR_FILENO   2
+#endif
+
+/* For wimlib */
+#define ftruncate       _chsize_s
+#define snwprintf(dst, count, ...)  _snwprintf_s(dst, count, _TRUNCATE, __VA_ARGS__)
+#define vsnwprintf      _vsnwprintf
