@@ -449,7 +449,7 @@ static DWORD WINAPI SearchProcessThread(LPVOID param)
 		// Work on our own copy of the handle names so we don't have to hold the
 		// mutex for string comparison. Update only if the version has changed.
 		if (blocking_process.nVersion[0] != blocking_process.nVersion[1]) {
-			if_not_assert(blocking_process.wHandleName != NULL && blocking_process.nHandles != 0) {
+			if_assert_fails(blocking_process.wHandleName != NULL && blocking_process.nHandles != 0) {
 				ReleaseMutex(hLock);
 				goto out;
 			}
@@ -697,7 +697,7 @@ static DWORD WINAPI SearchProcessThread(LPVOID param)
 
 out:
 	if (!bInitSuccess)
-		uprintf("Warning: Could not start process handle enumerator!");
+		uprintf("WARNING: Could not start process handle enumerator!");
 
 	if (wHandleName != NULL) {
 		for (j = 0; j < nHandles; j++)
@@ -807,11 +807,12 @@ BOOL SetProcessSearch(DWORD DeviceNum)
 		wHandleName[nHandles++] = utf8_to_wchar(DevPath);
 	free(PhysicalPath);
 	// Logical drive(s) handle name(s)
-	GetDriveLetters(DeviceNum, drive_letter);
-	for (i = 0; nHandles < MAX_NUM_HANDLES && drive_letter[i]; i++) {
-		drive_name[0] = drive_letter[i];
-		if (QueryDosDeviceA(drive_name, DevPath, sizeof(DevPath)) != 0)
-			wHandleName[nHandles++] = utf8_to_wchar(DevPath);
+	if (GetDriveLetters(DeviceNum, drive_letter)) {
+		for (i = 0; nHandles < MAX_NUM_HANDLES && drive_letter[i]; i++) {
+			drive_name[0] = drive_letter[i];
+			if (QueryDosDeviceA(drive_name, DevPath, sizeof(DevPath)) != 0)
+				wHandleName[nHandles++] = utf8_to_wchar(DevPath);
+		}
 	}
 	if (WaitForSingleObject(blocking_process.hLock, SEARCH_PROCESS_LOCK_TIMEOUT) != WAIT_OBJECT_0) {
 		uprintf("Could not obtain process search lock");
@@ -882,7 +883,7 @@ BYTE GetProcessSearch(uint32_t timeout, uint8_t access_mask, BOOL bIgnoreStalePr
 		return 0;
 	}
 
-	if_not_assert(blocking_process.hLock != NULL)
+	if_assert_fails(blocking_process.hLock != NULL)
 		return 0;
 
 retry:
